#!/bin/sh
curpath=`pwd`
scriptpath=${0%/*}
arguments=$*
tmpfile=tmp
cnffile=confirmed
ADBPATH=bin/adb

funcerr() {
  echo "設定に失敗しました. 以下の点を確認して再びこのスクリプトを実行してください."
  echo "1.Androidの設定より開発のUSBデバッグをONにしてください."
  echo "2.Androidで一度もFRepを起動していない場合は、いったんFRepを起動してください."
  echo "問題が解決しない場合は、下記サポートページ内FAQを参照してください."
  echo "http://strai.x0.com/frep-ja/faq#setup"
  cd $curpath
  exit 1
}

funcoffline() {
  echo "Android機器に表示されているUSBデバッグを許可してからEnterキーを押してください.(中止はCtrl+C)"
  read tmpinput
}

funcnumeric() {
  numcand=$1
  expr "$numcand" + 1 >/dev/null 2>&1
  # -lt 2 Numeric
  if [ $? -ge 2 ] ; then
    numcand=0
  fi
  echo $numcand
# return $numcand
}

funcdevice() {
  echo "複数のAndroid機器が接続されています."
  devnum=0
  $ADBPATH devices -l >$tmpfile
  # while~do~done with redirecting file because of variable lost.
  while read line ; do
    if [ -n "$line" ] ; then
      device="`echo $line | awk '{print $1}'`"
      if [ $devnum -gt 0 ] ; then
        echo "[$devnum] $line"
      fi
      devnum=`expr $devnum + 1`
    fi
  done <$tmpfile

  echo "設定する機器の番号を入力してください.(0でキャンセル)"
  read selnum
  seldevice=
  devnum=0
  selnum=`funcnumeric $selnum`

  if [ $selnum -eq 0 ] ; then
    echo "設定を中止しました."
    exit 0
  else
    # while~do~done with redirecting file because of variable lost.
    while read line ; do
    if [ -n "$line" ] ; then
      if [ $devnum -eq $selnum ] ; then
        seldevice="`echo $line | awk '{print $1}'`"
        break
      fi
      devnum=`expr $devnum + 1`
    fi
    done <$tmpfile
  fi
  rm $tmpfile

  if [ -n $seldevice ] ; then
    arguments="-s $seldevice"
    echo "[$selnum] $seldevice を選択しました."
  else
    echo "設定する機器1台のみ接続した状態で再度実行するか、あるいは設定する機器1台を"
    echo "オプション -s (上記シリアルの1つ) で指定してください."
    echo "例) mac.sh -s 00000000"
    exit 1
  fi
}

funcusbmode() {
  if [ -f $cnffile ] ; then
    return 0
  fi
  
  echo "  接続モードを充電のみ(一部機種ではファイル転送)に設定してください."
  echo ""
  echo "接続モードの確認後、Enterを入力してください.(以後表示しない場合は1を入力)"
  read selnum
  selnum=`funcnumeric $selnum`

  if [ $selnum -eq 1 ] ; then
    echo "次回から確認を省略します."
    touch $cnffile
  fi
}

cd $scriptpath
chmod +x $ADBPATH

$ADBPATH devices > /dev/null 2>&1

# check Android version and USB debug connection
passed=0
while [ $passed -eq 0 ] ; do
  versionsdk=`$ADBPATH $arguments shell getprop ro.build.version.sdk 2>&1`
  case $? in
    # passed (no error)
    0)
    passed=1
    ;;
    # error
    *)
    case $versionsdk in
      # skip sdk check when getprop denied or not found.
      *enied)
      passed=1
      ;;
      *getprop*found)
      passed=1
      ;;
      # error: more than one device/emulator (continue)
      *emulator)
      funcdevice
      ;;
      # error: device offline (continue)
      *offline)
      funcoffline
      ;;
      # error: device unauthorized (continue)
      *unauthorized*)
      funcoffline
      ;;
      # other error
      *)
      echo $versionsdk
      funcerr
      ;;
    esac
    ;;
  esac
done

# remove CR code
versionsdk=`echo $versionsdk | tr -c -d "0123456789"`
versionsdk=`funcnumeric $versionsdk`
# echo Android version_sdk: $versionsdk

# branch by Android version
if [ $versionsdk -ge 26 ] ; then
  echo "Android 8.0以降のためmac_alt.shを実行します."
  echo "- USBデバッグはONのまま利用してください."
  echo "- USBケーブルを抜いた状態での動作は現在のUSB接続モードに依存します."
  funcusbmode
  cd $curpath
  $scriptpath/mac_alt.sh $arguments
elif [ $versionsdk -ge 19 ] ; then
  echo "Android 4.4以降のためmac_alt.shを実行します."
  echo ""
  cd $curpath
  $scriptpath/mac_alt.sh $arguments
else
  echo "※Permission deniedと表示された場合は、mac_alt.shを実行してください."
  pushed=`$ADBPATH $arguments push bin/setup.sh /data/data/com.x0.strai.frep/app_bin/setup.sh 2>&1`
  case $? in
    0)
    # start setup script
    echo "Server Startedと表示されたらCtrl+Cを押してスクリプトを抜けてください."
    echo ""
    echo "sh /data/data/com.x0.strai.frep/app_bin/setup.sh &" | $ADBPATH $arguments shell
    ;;
    *)
    # push failed. if permission denied, retry on tmp.
    case $pushed in
      *denied)
      $ADBPATH $arguments push bin/setup.sh /data/local/tmp/setup.sh
      case $? in
        0)
        echo "sh /data/local/tmp/setup.sh &" | $ADBPATH $arguments shell
        ;;
        *)
        echo $pushed
        funcerr
        ;;
      esac
      ;;
      *)
      echo $pushed
      funcerr
      ;;
    esac
    ;;
  esac
fi

cd $curpath
exit 0

